@@ -1066,14 +1066,14 @@ class WordToken(caching.base.CachingMixin,models.Model):
             return 0.0
         prev = self.get_previous_word()
         pc = PrevCondProbs.objects.get_or_create(ActWord=self.WordType,PreviousWord=prev.WordType)[0]
-        return pc.getProb()
+        return pc.get_prob()
 
     def get_following_cond_prob(self):
         if self.before_pause():
             return 0.0
         foll = self.get_following_word()
         fc = FollCondProbs.objects.get_or_create(ActWord=self.WordType,FollowingWord=foll.WordType)[0]
-        return fc.getProb()
+        return fc.get_prob()
 
     def create_pictures(self):
         p = PraatLoader(settings.PRAAT_PATH,debug=settings.DEBUG)
